@@ -31,7 +31,7 @@
 #include <glib/gi18n-lib.h>
 #include <gio/gio.h>
 
-#include <gdbusutils.h>
+#include <gvfsdbusutils.h>
 
 #include "gproxydrive.h"
 #include "gproxyvolume.h"
@@ -69,16 +69,9 @@ struct _GProxyVolume {
 
 static void g_proxy_volume_volume_iface_init (GVolumeIface *iface);
 
-#define _G_IMPLEMENT_INTERFACE_DYNAMIC(TYPE_IFACE, iface_init)       { \
-  const GInterfaceInfo g_implement_interface_info = { \
-    (GInterfaceInitFunc) iface_init, NULL, NULL \
-  }; \
-  g_type_module_add_interface (type_module, g_define_type_id, TYPE_IFACE, &g_implement_interface_info); \
-}
-
 G_DEFINE_DYNAMIC_TYPE_EXTENDED (GProxyVolume, g_proxy_volume, G_TYPE_OBJECT, 0,
-                                _G_IMPLEMENT_INTERFACE_DYNAMIC (G_TYPE_VOLUME,
-                                                                g_proxy_volume_volume_iface_init))
+                                G_IMPLEMENT_INTERFACE_DYNAMIC (G_TYPE_VOLUME,
+                                                               g_proxy_volume_volume_iface_init))
 
 
 static void union_monitor_mount_added (GVolumeMonitor *union_monitor,
